diff --git a/composer/Plugin/Scaffold/Plugin.php b/composer/Plugin/Scaffold/Plugin.php
index 9a694ec349..2f5214fb22 100644
--- a/composer/Plugin/Scaffold/Plugin.php
+++ b/composer/Plugin/Scaffold/Plugin.php
@@ -103,7 +103,7 @@ public function postCmd(Event $event) {
   }
 
   /**
-   * Post package event behaviour.
+   * Post package event behavior.
    *
    * @param \Composer\Installer\PackageEvent $event
    *   Composer package event sent on install/update/remove.
diff --git a/core/assets/scaffold/files/default.settings.php b/core/assets/scaffold/files/default.settings.php
index 76e509abeb..45b0cca64e 100644
--- a/core/assets/scaffold/files/default.settings.php
+++ b/core/assets/scaffold/files/default.settings.php
@@ -440,7 +440,7 @@
 /**
  * Class Loader.
  *
- * If the APCu extension is detected, the classloader will be optimised to use
+ * If the APCu extension is detected, the classloader will be optimized to use
  * it. Set to FALSE to disable this.
  *
  * @see https://getcomposer.org/doc/articles/autoloader-optimization.md
diff --git a/core/assets/scaffold/files/example.settings.local.php b/core/assets/scaffold/files/example.settings.local.php
index 520cb4acd5..f91b9afb29 100644
--- a/core/assets/scaffold/files/example.settings.local.php
+++ b/core/assets/scaffold/files/example.settings.local.php
@@ -131,15 +131,15 @@
 $settings['skip_permissions_hardening'] = TRUE;
 
 /**
- * Exclude modules from configuration synchronisation.
+ * Exclude modules from configuration synchronization.
  *
  * On config export sync, no config or dependent config of any excluded module
  * is exported. On config import sync, any config of any installed excluded
  * module is ignored. In the exported configuration, it will be as if the
  * excluded module had never been installed. When syncing configuration, if an
  * excluded module is already installed, it will not be uninstalled by the
- * configuration synchronisation, and dependent configuration will remain
- * intact. This affects only configuration synchronisation; single import and
+ * configuration synchronization, and dependent configuration will remain
+ * intact. This affects only configuration synchronization; single import and
  * export of configuration are not affected.
  *
  * Drupal does not validate or sanity check the list of excluded modules. For
@@ -148,7 +148,7 @@
  * anymore.
  *
  * This is an advanced feature and using it means opting out of some of the
- * guarantees the configuration synchronisation provides. It is not recommended
+ * guarantees the configuration synchronization provides. It is not recommended
  * to use this feature with modules that affect Drupal in a major way such as
  * the language or field module.
  */
diff --git a/core/lib/Drupal/Core/Ajax/OpenOffCanvasDialogCommand.php b/core/lib/Drupal/Core/Ajax/OpenOffCanvasDialogCommand.php
index 78c406b3d8..ac7f6950a5 100644
--- a/core/lib/Drupal/Core/Ajax/OpenOffCanvasDialogCommand.php
+++ b/core/lib/Drupal/Core/Ajax/OpenOffCanvasDialogCommand.php
@@ -19,7 +19,7 @@ class OpenOffCanvasDialogCommand extends OpenDialogCommand {
    *
    * The off-canvas dialog differs from the normal modal provided by
    * OpenDialogCommand in that a off-canvas has built in positioning and
-   * behaviours. Drupal provides a built-in off-canvas dialog for this purpose,
+   * behaviors. Drupal provides a built-in off-canvas dialog for this purpose,
    * so the selector is hard-coded in the call to the parent constructor.
    *
    * @param string $title
diff --git a/core/lib/Drupal/Core/Config/ConfigEvents.php b/core/lib/Drupal/Core/Config/ConfigEvents.php
index 7686197d4e..349d95824a 100644
--- a/core/lib/Drupal/Core/Config/ConfigEvents.php
+++ b/core/lib/Drupal/Core/Config/ConfigEvents.php
@@ -154,7 +154,7 @@
    * Together with \Drupal\Core\Config\ConfigEvents::STORAGE_TRANSFORM_EXPORT
    * subscribers can alter the active configuration in a config sync workflow
    * instead of just overriding at runtime via the config-override system.
-   * This allows a complete customisation of the workflow including additional
+   * This allows a complete customization of the workflow including additional
    * modules and editable configuration in different environments.
    *
    * @code
diff --git a/core/lib/Drupal/Core/Config/ConfigFactory.php b/core/lib/Drupal/Core/Config/ConfigFactory.php
index e4496f88b7..fedd62a713 100644
--- a/core/lib/Drupal/Core/Config/ConfigFactory.php
+++ b/core/lib/Drupal/Core/Config/ConfigFactory.php
@@ -160,7 +160,7 @@ protected function doLoadMultiple(array $names, $immutable = TRUE) {
 
     // Pre-load remaining configuration files.
     if (!empty($names)) {
-      // Initialise override information.
+      // Initialize override information.
       $module_overrides = [];
       $storage_data = $this->storage->readMultiple($names);
 
diff --git a/core/lib/Drupal/Core/Config/Entity/ConfigEntityUpdater.php b/core/lib/Drupal/Core/Config/Entity/ConfigEntityUpdater.php
index 7ba77000ac..638a706ed1 100644
--- a/core/lib/Drupal/Core/Config/Entity/ConfigEntityUpdater.php
+++ b/core/lib/Drupal/Core/Config/Entity/ConfigEntityUpdater.php
@@ -83,7 +83,7 @@ public static function create(ContainerInterface $container) {
    *   save an entity. The callback can make changes to an entity. Note that all
    *   changes should comply with schema as an entity's data will not be
    *   validated against schema on save to avoid unexpected errors. If a
-   *   callback is not provided, the default behaviour is to update the
+   *   callback is not provided, the default behavior is to update the
    *   dependencies if required.
    *
    * @see hook_post_update_NAME()
@@ -113,7 +113,7 @@ public function update(array &$sandbox, $entity_type_id, callable $callback = NU
       $sandbox[self::SANDBOX_KEY]['count'] = count($sandbox[self::SANDBOX_KEY]['entities']);
     }
 
-    // The default behaviour is to fix dependencies.
+    // The default behavior is to fix dependencies.
     if ($callback === NULL) {
       $callback = function ($entity) {
         /** @var \Drupal\Core\Config\Entity\ConfigEntityInterface $entity */
diff --git a/core/lib/Drupal/Core/Config/ImportStorageTransformer.php b/core/lib/Drupal/Core/Config/ImportStorageTransformer.php
index 58fe795dd4..039516b31d 100644
--- a/core/lib/Drupal/Core/Config/ImportStorageTransformer.php
+++ b/core/lib/Drupal/Core/Config/ImportStorageTransformer.php
@@ -12,7 +12,7 @@
  * This service does not implement an interface and is final because it is not
  * meant to be replaced, extended or used in a different context.
  * Its single purpose is to transform a storage for the import step of a
- * configuration synchronisation by dispatching the import transformation event.
+ * configuration synchronization by dispatching the import transformation event.
  */
 final class ImportStorageTransformer {
 
diff --git a/core/lib/Drupal/Core/Database/Connection.php b/core/lib/Drupal/Core/Database/Connection.php
index 2afcd65c5c..9f6539174c 100644
--- a/core/lib/Drupal/Core/Database/Connection.php
+++ b/core/lib/Drupal/Core/Database/Connection.php
@@ -644,7 +644,7 @@ public function makeComment($comments) {
    * "/ * Exploit * / DROP TABLE node. -- * / UPDATE example SET field2=..."
    * @endcode
    *
-   * Unless the comment is sanitised first, the SQL server would drop the
+   * Unless the comment is sanitized first, the SQL server would drop the
    * node table and ignore the rest of the SQL statement.
    *
    * @param string $comment
diff --git a/core/lib/Drupal/Core/Entity/ContentEntityStorageBase.php b/core/lib/Drupal/Core/Entity/ContentEntityStorageBase.php
index 0d039060c3..7ad68edd6b 100644
--- a/core/lib/Drupal/Core/Entity/ContentEntityStorageBase.php
+++ b/core/lib/Drupal/Core/Entity/ContentEntityStorageBase.php
@@ -944,7 +944,7 @@ protected function populateAffectedRevisionTranslations(ContentEntityInterface $
    * @param array $ids
    *   The entity key values to verify.
    * @param string $entity_key
-   *   (optional) The entity key to sanitise values for. Defaults to 'id'.
+   *   (optional) The entity key to sanitize values for. Defaults to 'id'.
    *
    * @return array
    *   The sanitized list of entity key values.
diff --git a/core/lib/Drupal/Core/Entity/FieldableEntityStorageInterface.php b/core/lib/Drupal/Core/Entity/FieldableEntityStorageInterface.php
index 79c57f9dc5..933d8e0bc6 100644
--- a/core/lib/Drupal/Core/Entity/FieldableEntityStorageInterface.php
+++ b/core/lib/Drupal/Core/Entity/FieldableEntityStorageInterface.php
@@ -16,7 +16,7 @@
    * @param \Drupal\Core\Field\FieldStorageDefinitionInterface $storage_definition
    *   The field for which to count data records.
    * @param bool $as_bool
-   *   (Optional) Optimises the query for checking whether there are any records
+   *   (Optional) Optimizes the query for checking whether there are any records
    *   or not. Defaults to FALSE.
    *
    * @return bool|int
diff --git a/core/lib/Drupal/Core/Entity/entity.api.php b/core/lib/Drupal/Core/Entity/entity.api.php
index c7616fc2d0..7e1277fdd0 100644
--- a/core/lib/Drupal/Core/Entity/entity.api.php
+++ b/core/lib/Drupal/Core/Entity/entity.api.php
@@ -498,7 +498,7 @@
  * - \Drupal\Core\Entity\Routing\AdminHtmlRouteProvider provides the same
  *   routes, set up to use the administrative theme for edit and delete pages.
  * - You can also create your own class, extending one of these two classes if
- *   you only want to modify their behaviour slightly.
+ *   you only want to modify their behavior slightly.
  *
  * To register any route provider class, add lines like the following to your
  * entity class annotation:
diff --git a/core/lib/Drupal/Core/Installer/NormalInstallerServiceProvider.php b/core/lib/Drupal/Core/Installer/NormalInstallerServiceProvider.php
index 9127260b37..a29b7d8a77 100644
--- a/core/lib/Drupal/Core/Installer/NormalInstallerServiceProvider.php
+++ b/core/lib/Drupal/Core/Installer/NormalInstallerServiceProvider.php
@@ -14,7 +14,7 @@
  * $conf['container_service_providers'] and optimizes the container for
  * installation.
  *
- * Note that the early installer environment requires the further customisations
+ * Note that the early installer environment requires the further customizations
  * in InstallerServiceProvider.
  *
  * @see install_begin_request()
diff --git a/core/lib/Drupal/Core/Render/Renderer.php b/core/lib/Drupal/Core/Render/Renderer.php
index a07efce9e2..559c25624a 100644
--- a/core/lib/Drupal/Core/Render/Renderer.php
+++ b/core/lib/Drupal/Core/Render/Renderer.php
@@ -739,7 +739,7 @@ protected function ensureMarkupIsSafe(array $elements) {
       $elements['#markup'] = Markup::create(Html::escape($elements['#plain_text']));
     }
     elseif (!($elements['#markup'] instanceof MarkupInterface)) {
-      // The default behaviour is to XSS filter using the admin tag list.
+      // The default behavior is to XSS filter using the admin tag list.
       $tags = isset($elements['#allowed_tags']) ? $elements['#allowed_tags'] : Xss::getAdminTagList();
       $elements['#markup'] = Markup::create(Xss::filter($elements['#markup'], $tags));
     }
diff --git a/core/lib/Drupal/Core/Update/UpdateServiceProvider.php b/core/lib/Drupal/Core/Update/UpdateServiceProvider.php
index c663e9ae64..ca1d66b87c 100644
--- a/core/lib/Drupal/Core/Update/UpdateServiceProvider.php
+++ b/core/lib/Drupal/Core/Update/UpdateServiceProvider.php
@@ -10,7 +10,7 @@
 use Symfony\Component\DependencyInjection\Reference;
 
 /**
- * Customises the container for running updates.
+ * Customizes the container for running updates.
  */
 class UpdateServiceProvider implements ServiceProviderInterface, ServiceModifierInterface {
 
diff --git a/core/misc/entity-form.es6.js b/core/misc/entity-form.es6.js
index a9a10c273c..6ccae70bcb 100644
--- a/core/misc/entity-form.es6.js
+++ b/core/misc/entity-form.es6.js
@@ -10,7 +10,7 @@
    * @type {Drupal~behavior}
    *
    * @prop {Drupal~behaviorAttach} attach
-   *   Attaches summary behaviour entity form tabs.
+   *   Attaches summary behavior entity form tabs.
    *
    *   Specifically, it updates summaries to the revision information and the
    *   translation options.
diff --git a/core/modules/block/js/block.es6.js b/core/modules/block/js/block.es6.js
index 68af99546b..2fe26a6dce 100644
--- a/core/modules/block/js/block.es6.js
+++ b/core/modules/block/js/block.es6.js
@@ -73,7 +73,7 @@
    * @type {Drupal~behavior}
    *
    * @prop {Drupal~behaviorAttach} attach
-   *   Attaches the tableDrag behaviour for blocks in block administration.
+   *   Attaches the tableDrag behavior for blocks in block administration.
    */
   Drupal.behaviors.blockDrag = {
     attach(context, settings) {
diff --git a/core/modules/ckeditor/js/ckeditor.admin.es6.js b/core/modules/ckeditor/js/ckeditor.admin.es6.js
index b4c2d217cd..3836a5bb39 100644
--- a/core/modules/ckeditor/js/ckeditor.admin.es6.js
+++ b/core/modules/ckeditor/js/ckeditor.admin.es6.js
@@ -7,14 +7,14 @@
   Drupal.ckeditor = Drupal.ckeditor || {};
 
   /**
-   * Sets config behaviour and creates config views for the CKEditor toolbar.
+   * Sets config behavior and creates config views for the CKEditor toolbar.
    *
    * @type {Drupal~behavior}
    *
    * @prop {Drupal~behaviorAttach} attach
-   *   Attaches admin behaviour to the CKEditor buttons.
+   *   Attaches admin behavior to the CKEditor buttons.
    * @prop {Drupal~behaviorDetach} detach
-   *   Detaches admin behaviour from the CKEditor buttons on 'unload'.
+   *   Detaches admin behavior from the CKEditor buttons on 'unload'.
    */
   Drupal.behaviors.ckeditorAdmin = {
     attach(context) {
@@ -412,7 +412,7 @@
    * @type {Drupal~behavior}
    *
    * @prop {Drupal~behaviorAttach} attach
-   *   Attaches show/hide behaviour to Plugin Settings buttons.
+   *   Attaches show/hide behavior to Plugin Settings buttons.
    */
   Drupal.behaviors.ckeditorAdminButtonPluginSettings = {
     attach(context) {
diff --git a/core/modules/ckeditor/js/ckeditor.drupalimage.admin.es6.js b/core/modules/ckeditor/js/ckeditor.drupalimage.admin.es6.js
index 557379436d..b07267efec 100644
--- a/core/modules/ckeditor/js/ckeditor.drupalimage.admin.es6.js
+++ b/core/modules/ckeditor/js/ckeditor.drupalimage.admin.es6.js
@@ -10,7 +10,7 @@
    * @type {Drupal~behavior}
    *
    * @prop {Drupal~behaviorAttach} attach
-   *   Attaches summary behaviour to the "drupalimage" settings vertical tab.
+   *   Attaches summary behavior to the "drupalimage" settings vertical tab.
    */
   Drupal.behaviors.ckeditorDrupalImageSettingsSummary = {
     attach() {
diff --git a/core/modules/ckeditor/js/ckeditor.stylescombo.admin.es6.js b/core/modules/ckeditor/js/ckeditor.stylescombo.admin.es6.js
index b87e6b3186..48f175db72 100644
--- a/core/modules/ckeditor/js/ckeditor.stylescombo.admin.es6.js
+++ b/core/modules/ckeditor/js/ckeditor.stylescombo.admin.es6.js
@@ -15,7 +15,7 @@
    * @type {Drupal~behavior}
    *
    * @prop {Drupal~behaviorAttach} attach
-   *   Attaches admin behaviour to the "stylescombo" button.
+   *   Attaches admin behavior to the "stylescombo" button.
    */
   Drupal.behaviors.ckeditorStylesComboSettings = {
     attach(context) {
@@ -110,7 +110,7 @@
    * @type {Drupal~behavior}
    *
    * @prop {Drupal~behaviorAttach} attach
-   *   Attaches summary behaviour to the plugin settings vertical tab.
+   *   Attaches summary behavior to the plugin settings vertical tab.
    */
   Drupal.behaviors.ckeditorStylesComboSettingsSummary = {
     attach() {
diff --git a/core/modules/ckeditor/js/plugins/drupalimage/plugin.es6.js b/core/modules/ckeditor/js/plugins/drupalimage/plugin.es6.js
index 88add4f4ba..3b19c02591 100644
--- a/core/modules/ckeditor/js/plugins/drupalimage/plugin.es6.js
+++ b/core/modules/ckeditor/js/plugins/drupalimage/plugin.es6.js
@@ -49,7 +49,7 @@
 
     CKEDITOR.plugins.drupallink.registerLinkableWidget('image');
 
-    // Override default behaviour of 'drupalunlink' command.
+    // Override default behavior of 'drupalunlink' command.
     editor.getCommand('drupalunlink').on('exec', function(evt) {
       const widget = getFocusedWidget(editor);
 
diff --git a/core/modules/color/preview.es6.js b/core/modules/color/preview.es6.js
index cb716e2477..ec1da65a70 100644
--- a/core/modules/color/preview.es6.js
+++ b/core/modules/color/preview.es6.js
@@ -14,11 +14,11 @@
      * The callback for when the color preview has been attached.
      *
      * @param {Element} context
-     *   The context to initiate the color behaviour.
+     *   The context to initiate the color behavior.
      * @param {object} settings
      *   Settings for the color functionality.
      * @param {HTMLFormElement} form
-     *   The form to initiate the color behaviour on.
+     *   The form to initiate the color behavior on.
      * @param {object} farb
      *   The farbtastic object.
      * @param {number} height
diff --git a/core/modules/config/tests/src/Functional/ConfigLanguageOverrideWebTest.php b/core/modules/config/tests/src/Functional/ConfigLanguageOverrideWebTest.php
index 79bb74e608..5088066c08 100644
--- a/core/modules/config/tests/src/Functional/ConfigLanguageOverrideWebTest.php
+++ b/core/modules/config/tests/src/Functional/ConfigLanguageOverrideWebTest.php
@@ -71,7 +71,7 @@ public function testSiteNameTranslation() {
     // determine the front page. This occurs before language negotiation causing
     // the configuration factory to cache an object without the correct
     // overrides. We are testing that the configuration factory is
-    // re-initialised after language negotiation. Ensure that it applies when
+    // re-initialized after language negotiation. Ensure that it applies when
     // we access the XX front page.
     // @see \Drupal\Core\PathProcessor::processInbound()
     $this->drupalGet('xx');
diff --git a/core/modules/config_translation/tests/src/Functional/ConfigTranslationDateFormatUiTest.php b/core/modules/config_translation/tests/src/Functional/ConfigTranslationDateFormatUiTest.php
index d82492f966..5fbd38bd5c 100644
--- a/core/modules/config_translation/tests/src/Functional/ConfigTranslationDateFormatUiTest.php
+++ b/core/modules/config_translation/tests/src/Functional/ConfigTranslationDateFormatUiTest.php
@@ -6,7 +6,7 @@
 use Drupal\Tests\BrowserTestBase;
 
 /**
- * Tests the content translation behaviours on date formats.
+ * Tests the content translation behaviors on date formats.
  *
  * @group config_translation
  */
@@ -40,7 +40,7 @@ protected function setUp(): void {
   }
 
   /**
-   * Tests date format translation behaviour.
+   * Tests date format translation behavior.
    */
   public function testDateFormatUI() {
     $this->drupalGet('admin/config/regional/date-time');
diff --git a/core/modules/content_moderation/tests/src/Kernel/ModerationStateFieldItemListTest.php b/core/modules/content_moderation/tests/src/Kernel/ModerationStateFieldItemListTest.php
index 941f34d7a5..0e74b1ae0e 100644
--- a/core/modules/content_moderation/tests/src/Kernel/ModerationStateFieldItemListTest.php
+++ b/core/modules/content_moderation/tests/src/Kernel/ModerationStateFieldItemListTest.php
@@ -337,9 +337,9 @@ public function moderatedEntityWithExistingIdTestCases() {
   }
 
   /**
-   * Test customising the default moderation state.
+   * Test customizing the default moderation state.
    */
-  public function testWorkflowCustomisedInitialState() {
+  public function testWorkflowCustomizedInitialState() {
     $workflow = Workflow::load('editorial');
     $configuration = $workflow->getTypePlugin()->getConfiguration();
 
diff --git a/core/modules/content_translation/tests/src/Functional/ContentTranslationEntityBundleUITest.php b/core/modules/content_translation/tests/src/Functional/ContentTranslationEntityBundleUITest.php
index 757daab1ee..9c6338ba91 100644
--- a/core/modules/content_translation/tests/src/Functional/ContentTranslationEntityBundleUITest.php
+++ b/core/modules/content_translation/tests/src/Functional/ContentTranslationEntityBundleUITest.php
@@ -5,7 +5,7 @@
 use Drupal\Tests\BrowserTestBase;
 
 /**
- * Tests the content translation behaviours on entity bundle UI.
+ * Tests the content translation behaviors on entity bundle UI.
  *
  * @group content_translation
  */
@@ -31,7 +31,7 @@ protected function setUp(): void {
   }
 
   /**
-   * Tests content types default translation behaviour.
+   * Tests content types default translation behavior.
    */
   public function testContentTypeUI() {
     // Create first content type.
diff --git a/core/modules/field_ui/src/Plugin/Derivative/FieldUiLocalTask.php b/core/modules/field_ui/src/Plugin/Derivative/FieldUiLocalTask.php
index ff97582c8a..e762ab572e 100644
--- a/core/modules/field_ui/src/Plugin/Derivative/FieldUiLocalTask.php
+++ b/core/modules/field_ui/src/Plugin/Derivative/FieldUiLocalTask.php
@@ -118,7 +118,7 @@ public function getDerivativeDefinitions($base_plugin_definition) {
         // The same base $path for the menu item (with a placeholder) can be
         // used for all bundles of a given entity type; but depending on
         // administrator settings, each bundle has a different set of view
-        // modes available for customisation. So we define menu items for all
+        // modes available for customization. So we define menu items for all
         // view modes, and use a route requirement to determine which ones are
         // actually visible for a given bundle.
         $this->derivatives['field_form_display_default_' . $entity_type_id] = [
diff --git a/core/modules/hal/src/Normalizer/EntityReferenceItemNormalizer.php b/core/modules/hal/src/Normalizer/EntityReferenceItemNormalizer.php
index c2d65bfdbc..1c9d529570 100644
--- a/core/modules/hal/src/Normalizer/EntityReferenceItemNormalizer.php
+++ b/core/modules/hal/src/Normalizer/EntityReferenceItemNormalizer.php
@@ -84,7 +84,7 @@ public function normalize($field_item, $format = NULL, array $context = []) {
     $embedded = $this->serializer->normalize($target_entity, $format, $context);
     // @todo https://www.drupal.org/project/drupal/issues/3110815 $embedded will
     //   be NULL if the target entity does not exist. Use null coalescence
-    //   operator to preserve behaviour in PHP 7.4.
+    //   operator to preserve behavior in PHP 7.4.
     $link = $embedded['_links']['self'] ?? NULL;
     // If the field is translatable, add the langcode to the link relation
     // object. This does not indicate the language of the target entity.
diff --git a/core/modules/language/src/Form/LanguageAddForm.php b/core/modules/language/src/Form/LanguageAddForm.php
index 8e0b9b3963..22d569f64e 100644
--- a/core/modules/language/src/Form/LanguageAddForm.php
+++ b/core/modules/language/src/Form/LanguageAddForm.php
@@ -19,7 +19,7 @@ class LanguageAddForm extends LanguageFormBase {
    * {@inheritdoc}
    */
   public function getFormId() {
-    // @todo Remove in favour of base method.
+    // @todo Remove in favor of base method.
     return 'language_admin_add_form';
   }
 
diff --git a/core/modules/language/src/Form/LanguageEditForm.php b/core/modules/language/src/Form/LanguageEditForm.php
index 80b6a21450..c27b379cdf 100644
--- a/core/modules/language/src/Form/LanguageEditForm.php
+++ b/core/modules/language/src/Form/LanguageEditForm.php
@@ -15,7 +15,7 @@ class LanguageEditForm extends LanguageFormBase {
    * {@inheritdoc}
    */
   public function getFormId() {
-    // @todo Remove in favour of base method.
+    // @todo Remove in favor of base method.
     return 'language_admin_edit_form';
   }
 
diff --git a/core/modules/locale/tests/modules/locale_test_development_release/locale_test_development_release.info.yml b/core/modules/locale/tests/modules/locale_test_development_release/locale_test_development_release.info.yml
index 199766b612..6ecdeabe9f 100644
--- a/core/modules/locale/tests/modules/locale_test_development_release/locale_test_development_release.info.yml
+++ b/core/modules/locale/tests/modules/locale_test_development_release/locale_test_development_release.info.yml
@@ -1,6 +1,6 @@
 name: 'Locale Test Development Release'
 type: module
-description: 'Helper module to test the behaviour when the core verison is a development release.'
+description: 'Helper module to test the behavior when the core verison is a development release.'
 package: Testing
 version: VERSION
 hidden: true
diff --git a/core/modules/migrate_drupal/src/Plugin/migrate/process/NodeCompleteNodeLookup.php b/core/modules/migrate_drupal/src/Plugin/migrate/process/NodeCompleteNodeLookup.php
index bd5e5d069d..2c2defce03 100644
--- a/core/modules/migrate_drupal/src/Plugin/migrate/process/NodeCompleteNodeLookup.php
+++ b/core/modules/migrate_drupal/src/Plugin/migrate/process/NodeCompleteNodeLookup.php
@@ -14,7 +14,7 @@
  * migration. The classic node migration and complete node migration have a
  * different number of destination keys. This process plugin will ensure that
  * when the complete node migration is used in the lookup the nid value is
- * returned. This keeps the behaviour the same as the classic node migration.
+ * returned. This keeps the behavior the same as the classic node migration.
  *
  * @see \Drupal\migrate\Plugin\MigrateProcessInterface
  *
diff --git a/core/modules/migrate_drupal/src/Plugin/migrate/process/NodeCompleteNodeRevisionLookup.php b/core/modules/migrate_drupal/src/Plugin/migrate/process/NodeCompleteNodeRevisionLookup.php
index 7416e6561a..f1bc5a9d3c 100644
--- a/core/modules/migrate_drupal/src/Plugin/migrate/process/NodeCompleteNodeRevisionLookup.php
+++ b/core/modules/migrate_drupal/src/Plugin/migrate/process/NodeCompleteNodeRevisionLookup.php
@@ -14,7 +14,7 @@
  * migration. The classic node migration and complete node migration have a
  * different number of destination keys. This process plugin will ensure that
  * when the complete node migration is used in the lookup the vid value is
- * returned. This keeps the behaviour the same as the classic node migration.
+ * returned. This keeps the behavior the same as the classic node migration.
  *
  * @see \Drupal\migrate\Plugin\MigrateProcessInterface
  *
diff --git a/core/modules/migrate_drupal/src/Plugin/migrate/process/NodeCompleteNodeTranslationLookup.php b/core/modules/migrate_drupal/src/Plugin/migrate/process/NodeCompleteNodeTranslationLookup.php
index 671d9fe708..9722273af1 100644
--- a/core/modules/migrate_drupal/src/Plugin/migrate/process/NodeCompleteNodeTranslationLookup.php
+++ b/core/modules/migrate_drupal/src/Plugin/migrate/process/NodeCompleteNodeTranslationLookup.php
@@ -14,7 +14,7 @@
  * migration. The classic node migration and complete node migration have a
  * different number of destination keys. This process plugin will ensure that
  * when the complete node migration is used in the lookup the nid and langcode
- * values are returned. This keeps the behaviour the same as the classic node
+ * values are returned. This keeps the behavior the same as the classic node
  * migration.
  *
  * @see \Drupal\migrate\Plugin\MigrateProcessInterface
diff --git a/core/modules/node/src/NodeViewsData.php b/core/modules/node/src/NodeViewsData.php
index 86db01c34f..32aa04c725 100644
--- a/core/modules/node/src/NodeViewsData.php
+++ b/core/modules/node/src/NodeViewsData.php
@@ -208,7 +208,7 @@ public function getViewsData() {
       'id' => 'node_nid',
       'numeric' => TRUE,
     ];
-    // @todo the NID field needs different behaviour on revision/non-revision
+    // @todo the NID field needs different behavior on revision/non-revision
     //   tables. It would be neat if this could be encoded in the base field
     //   definition.
     $data['node_field_revision']['nid']['relationship']['id'] = 'standard';
diff --git a/core/modules/serialization/tests/src/Kernel/EntitySerializationTest.php b/core/modules/serialization/tests/src/Kernel/EntitySerializationTest.php
index deb60ebe99..93945e5b8f 100644
--- a/core/modules/serialization/tests/src/Kernel/EntitySerializationTest.php
+++ b/core/modules/serialization/tests/src/Kernel/EntitySerializationTest.php
@@ -244,7 +244,7 @@ public function testSerialize() {
       'non_rev_field' => '<non_rev_field/>',
       'field_test_text' => '<field_test_text><value>' . $this->values['field_test_text']['value'] . '</value><format>' . $this->values['field_test_text']['format'] . '</format><processed><![CDATA[<p>' . $this->values['field_test_text']['value'] . '</p>]]></processed></field_test_text>',
     ];
-    // Sort it in the same order as normalised.
+    // Sort it in the same order as normalized.
     $expected = array_merge($normalized, $expected);
     // Add header and footer.
     array_unshift($expected, '<?xml version="1.0"?>' . PHP_EOL . '<response>');
diff --git a/core/modules/system/tests/modules/form_test/src/Form/FormTestTableForm.php b/core/modules/system/tests/modules/form_test/src/Form/FormTestTableForm.php
index 8196d4d6f6..2004933135 100644
--- a/core/modules/system/tests/modules/form_test/src/Form/FormTestTableForm.php
+++ b/core/modules/system/tests/modules/form_test/src/Form/FormTestTableForm.php
@@ -35,7 +35,7 @@ public function buildForm(array $form, FormStateInterface $form_state) {
     ];
     $form['table']['another_row'] = [
       'data' => [
-        '#title' => $this->t('my favourite fruit is <strong>@fruit</strong>', ['@fruit' => 'bananas']),
+        '#title' => $this->t('my favorite fruit is <strong>@fruit</strong>', ['@fruit' => 'bananas']),
         '#markup' => '<p>some more text</p>',
       ],
     ];
diff --git a/core/modules/system/tests/src/Functional/Menu/LocalActionTest.php b/core/modules/system/tests/src/Functional/Menu/LocalActionTest.php
index a98a7c2b7e..42b622ce2c 100644
--- a/core/modules/system/tests/src/Functional/Menu/LocalActionTest.php
+++ b/core/modules/system/tests/src/Functional/Menu/LocalActionTest.php
@@ -82,7 +82,7 @@ protected function assertLocalAction(array $actions) {
       list($url, $title) = $action;
       // SimpleXML gives us the unescaped text, not the actual escaped markup,
       // so use a pattern instead to check the raw content.
-      // This behaviour is a bug in libxml, see
+      // This behavior is a bug in libxml, see
       // https://bugs.php.net/bug.php?id=49437.
       $this->assertPattern('@<a [^>]*class="[^"]*button-action[^"]*"[^>]*>' . preg_quote($title, '@') . '</@');
       $this->assertEqual($elements[$index]->getAttribute('href'), $url->toString());
diff --git a/core/modules/system/tests/src/Functional/Menu/LocalTasksTest.php b/core/modules/system/tests/src/Functional/Menu/LocalTasksTest.php
index c6b596bf36..22ee3c0505 100644
--- a/core/modules/system/tests/src/Functional/Menu/LocalTasksTest.php
+++ b/core/modules/system/tests/src/Functional/Menu/LocalTasksTest.php
@@ -82,7 +82,7 @@ protected function assertLocalTasks(array $routes, $level = 0) {
   protected function assertLocalTaskAppers($title) {
     // SimpleXML gives us the unescaped text, not the actual escaped markup,
     // so use a pattern instead to check the raw content.
-    // This behaviour is a bug in libxml, see
+    // This behavior is a bug in libxml, see
     // https://bugs.php.net/bug.php?id=49437.
     return $this->assertPattern('@<a [^>]*>' . preg_quote($title, '@') . '</a>@');
   }
diff --git a/core/modules/system/tests/src/Functional/UpdateSystem/UpdatePostUpdateTest.php b/core/modules/system/tests/src/Functional/UpdateSystem/UpdatePostUpdateTest.php
index 8ba22aadb4..99265399e6 100644
--- a/core/modules/system/tests/src/Functional/UpdateSystem/UpdatePostUpdateTest.php
+++ b/core/modules/system/tests/src/Functional/UpdateSystem/UpdatePostUpdateTest.php
@@ -55,7 +55,7 @@ protected function setUp(): void {
       ->condition('name', 'core.extension')
       ->execute();
 
-    // Mimic the behaviour of ModuleInstaller::install() for removed post
+    // Mimic the behavior of ModuleInstaller::install() for removed post
     // updates. Don't include the actual post updates because we want them to
     // run.
     $key_value = \Drupal::service('keyvalue');
diff --git a/core/modules/system/tests/src/Functional/UpdateSystem/UpdateRemovedPostUpdateTest.php b/core/modules/system/tests/src/Functional/UpdateSystem/UpdateRemovedPostUpdateTest.php
index 262cb27b67..f29012e308 100644
--- a/core/modules/system/tests/src/Functional/UpdateSystem/UpdateRemovedPostUpdateTest.php
+++ b/core/modules/system/tests/src/Functional/UpdateSystem/UpdateRemovedPostUpdateTest.php
@@ -63,7 +63,7 @@ protected function setUp(): void {
    * Tests hook_post_update_NAME().
    */
   public function testRemovedPostUpdate() {
-    // Mimic the behaviour of ModuleInstaller::install().
+    // Mimic the behavior of ModuleInstaller::install().
     $key_value = \Drupal::service('keyvalue');
     $existing_updates = $key_value->get('post_update')->get('existing_updates', []);
 
diff --git a/core/modules/views/js/ajax_view.es6.js b/core/modules/views/js/ajax_view.es6.js
index 55c85fda18..cbcec78ffc 100644
--- a/core/modules/views/js/ajax_view.es6.js
+++ b/core/modules/views/js/ajax_view.es6.js
@@ -137,7 +137,7 @@
   Drupal.views.ajaxView.prototype.attachExposedFormAjax = function() {
     const that = this;
     this.exposedFormAjax = [];
-    // Exclude the reset buttons so no AJAX behaviours are bound. Many things
+    // Exclude the reset buttons so no AJAX behaviors are bound. Many things
     // break during the form reset phase if using AJAX.
     $('input[type=submit], input[type=image]', this.$exposed_form)
       .not('[data-drupal-selector=edit-reset]')
diff --git a/core/modules/views/tests/src/Kernel/ViewExecutableTest.php b/core/modules/views/tests/src/Kernel/ViewExecutableTest.php
index 1e5b716334..831187b31f 100644
--- a/core/modules/views/tests/src/Kernel/ViewExecutableTest.php
+++ b/core/modules/views/tests/src/Kernel/ViewExecutableTest.php
@@ -527,7 +527,7 @@ public function testSerialization() {
     // Serialize the ViewExecutable as part of other data.
     unserialize(serialize(['SOMETHING UNEXPECTED', $view_executable]));
 
-    // Make sure the serialisation of the ViewExecutable didn't influence the
+    // Make sure the serialization of the ViewExecutable didn't influence the
     // field definitions.
     $nid_definition_after = $field_manager->getBaseFieldDefinitions('node')['nid']
       ->getItemDefinition()
diff --git a/core/modules/views_ui/src/ViewUI.php b/core/modules/views_ui/src/ViewUI.php
index b5a1e11c50..056c7ea0c3 100644
--- a/core/modules/views_ui/src/ViewUI.php
+++ b/core/modules/views_ui/src/ViewUI.php
@@ -611,7 +611,7 @@ public function renderPreview($display_id, $args = []) {
 
       // Prepare the query information and statistics to show either above or
       // below the view preview.
-      // Initialise the empty rows arrays so we can safely merge them later.
+      // Initialize the empty rows arrays so we can safely merge them later.
       $rows['query'] = [];
       $rows['statistics'] = [];
       if ($show_info || $show_query || $show_stats) {
diff --git a/core/modules/workspaces/tests/src/FunctionalJavascript/WorkspaceToolbarIntegrationTest.php b/core/modules/workspaces/tests/src/FunctionalJavascript/WorkspaceToolbarIntegrationTest.php
index 5655fd7b9b..2ec2353a05 100644
--- a/core/modules/workspaces/tests/src/FunctionalJavascript/WorkspaceToolbarIntegrationTest.php
+++ b/core/modules/workspaces/tests/src/FunctionalJavascript/WorkspaceToolbarIntegrationTest.php
@@ -59,7 +59,7 @@ public function testWorkspaceCanvasToggling() {
   }
 
   /**
-   * Test workspace switch and landing page behaviour.
+   * Test workspace switch and landing page behavior.
    */
   public function testWorkspaceSwitch() {
     $page = $this->getSession()->getPage();
diff --git a/core/profiles/demo_umami/themes/umami/css/base.css b/core/profiles/demo_umami/themes/umami/css/base.css
index f0d02288cd..c5ae295fff 100644
--- a/core/profiles/demo_umami/themes/umami/css/base.css
+++ b/core/profiles/demo_umami/themes/umami/css/base.css
@@ -77,7 +77,7 @@ blockquote > * {
   line-height: 1.5;
 }
 blockquote a {
-  /* Tweak default link colour to improve contrast for accessibility */
+  /* Tweak default link color to improve contrast for accessibility */
   color: #057d6d;
 }
 blockquote a:hover,
diff --git a/core/tests/Drupal/FunctionalJavascriptTests/WebDriverTestBase.php b/core/tests/Drupal/FunctionalJavascriptTests/WebDriverTestBase.php
index c855fca22c..503974c928 100644
--- a/core/tests/Drupal/FunctionalJavascriptTests/WebDriverTestBase.php
+++ b/core/tests/Drupal/FunctionalJavascriptTests/WebDriverTestBase.php
@@ -142,7 +142,7 @@ protected function assertJsCondition($condition, $timeout = 10000, $message = ''
    *   example, /tmp/test_screenshot.jpg.
    * @param bool $set_background_color
    *   (optional) By default this method will set the background color to white.
-   *   Set to FALSE to override this behaviour.
+   *   Set to FALSE to override this behavior.
    *
    * @throws \Behat\Mink\Exception\UnsupportedDriverActionException
    *   When operation not supported by the driver.
diff --git a/core/tests/Drupal/KernelTests/Core/Database/SelectTest.php b/core/tests/Drupal/KernelTests/Core/Database/SelectTest.php
index f5f7954767..fb7cd83551 100644
--- a/core/tests/Drupal/KernelTests/Core/Database/SelectTest.php
+++ b/core/tests/Drupal/KernelTests/Core/Database/SelectTest.php
@@ -58,7 +58,7 @@ public function testVulnerableComment() {
 
     // Check the returned number of rows.
     $this->assertCount(4, $records);
-    // Check that the flattened query contains the sanitised comment string.
+    // Check that the flattened query contains the sanitized comment string.
     $this->assertStringContainsString($expected, $query);
 
     $connection = Database::getConnection();
diff --git a/core/tests/Drupal/KernelTests/Core/Entity/EntityQueryTest.php b/core/tests/Drupal/KernelTests/Core/Entity/EntityQueryTest.php
index 18d62125e9..6fb012bdcc 100644
--- a/core/tests/Drupal/KernelTests/Core/Entity/EntityQueryTest.php
+++ b/core/tests/Drupal/KernelTests/Core/Entity/EntityQueryTest.php
@@ -565,7 +565,7 @@ public function testNestedConditionGroups() {
    */
   public function testConditionCount() {
     // Query for all entities of the first bundle that
-    // have red as a colour AND are triangle shaped.
+    // have red as a color AND are triangle shaped.
     $query = $this->storage->getQuery();
 
     // Add an AND condition group with 2 conditions in it.
diff --git a/core/tests/Drupal/KernelTests/Core/Form/ExternalFormUrlTest.php b/core/tests/Drupal/KernelTests/Core/Form/ExternalFormUrlTest.php
index dd610abf7c..9c7aae1d80 100644
--- a/core/tests/Drupal/KernelTests/Core/Form/ExternalFormUrlTest.php
+++ b/core/tests/Drupal/KernelTests/Core/Form/ExternalFormUrlTest.php
@@ -65,7 +65,7 @@ protected function setUp(): void {
   }
 
   /**
-   * Tests form behaviour.
+   * Tests form behavior.
    */
   public function testActionUrlBehavior() {
     // Create a new request which has a request uri with multiple leading
diff --git a/core/tests/Drupal/KernelTests/Core/Render/Element/TableTest.php b/core/tests/Drupal/KernelTests/Core/Render/Element/TableTest.php
index 04cd66edcc..db3086cb48 100644
--- a/core/tests/Drupal/KernelTests/Core/Render/Element/TableTest.php
+++ b/core/tests/Drupal/KernelTests/Core/Render/Element/TableTest.php
@@ -305,7 +305,7 @@ public function testThemeTableTitle() {
     $form = \Drupal::formBuilder()->getForm('\Drupal\form_test\Form\FormTestTableForm');
     $this->render($form);
     $this->assertEscaped('Update <em>kitten</em>');
-    $this->assertRaw('Update my favourite fruit is <strong>bananas</strong>');
+    $this->assertRaw('Update my favorite fruit is <strong>bananas</strong>');
   }
 
 }
diff --git a/core/tests/Drupal/KernelTests/Core/Render/RenderTest.php b/core/tests/Drupal/KernelTests/Core/Render/RenderTest.php
index b0e3d8094a..f35f310dd3 100644
--- a/core/tests/Drupal/KernelTests/Core/Render/RenderTest.php
+++ b/core/tests/Drupal/KernelTests/Core/Render/RenderTest.php
@@ -48,7 +48,7 @@ public function testDrupalRenderThemePreprocessAttached() {
    */
   public function testRenderChildren() {
     // Ensure that #prefix and #suffix is only being printed once since that is
-    // the behaviour the caller code expects.
+    // the behavior the caller code expects.
     $build = [
       '#type' => 'container',
       '#theme' => 'theme_test_render_element_children',
diff --git a/core/tests/Drupal/KernelTests/Core/Test/Comparator/MarkupInterfaceComparatorTest.php b/core/tests/Drupal/KernelTests/Core/Test/Comparator/MarkupInterfaceComparatorTest.php
index b824ba49f2..4a72a3dc42 100644
--- a/core/tests/Drupal/KernelTests/Core/Test/Comparator/MarkupInterfaceComparatorTest.php
+++ b/core/tests/Drupal/KernelTests/Core/Test/Comparator/MarkupInterfaceComparatorTest.php
@@ -14,7 +14,7 @@
  * Tests \Drupal\TestTools\Comparator\MarkupInterfaceComparator.
  *
  * We need to test the class with a kernel test since casting MarkupInterface
- * objects to strings can require an initialised container.
+ * objects to strings can require an initialized container.
  *
  * @group Test
  *
diff --git a/core/tests/Drupal/KernelTests/Core/Theme/ThemeSettingsTest.php b/core/tests/Drupal/KernelTests/Core/Theme/ThemeSettingsTest.php
index e35f6291fb..b099d0cad8 100644
--- a/core/tests/Drupal/KernelTests/Core/Theme/ThemeSettingsTest.php
+++ b/core/tests/Drupal/KernelTests/Core/Theme/ThemeSettingsTest.php
@@ -71,7 +71,7 @@ public function testLogoConfig() {
     $theme_handler = $this->container->get('theme_handler');
     $theme = $theme_handler->getTheme('stark');
 
-    // Tests default behaviour.
+    // Tests default behavior.
     $expected = '/' . $theme->getPath() . '/logo.svg';
     $this->assertEquals($expected, theme_get_setting('logo.url', 'stark'));
 
diff --git a/core/tests/Drupal/KernelTests/Core/Theme/TwigMarkupInterfaceTest.php b/core/tests/Drupal/KernelTests/Core/Theme/TwigMarkupInterfaceTest.php
index 3948062f2b..01e4d2e3d2 100644
--- a/core/tests/Drupal/KernelTests/Core/Theme/TwigMarkupInterfaceTest.php
+++ b/core/tests/Drupal/KernelTests/Core/Theme/TwigMarkupInterfaceTest.php
@@ -63,7 +63,7 @@ public function providerTestMarkupInterfaceEmpty() {
   }
 
   /**
-   * Tests behaviour if a string is translated to become an empty string.
+   * Tests behavior if a string is translated to become an empty string.
    */
   public function testEmptyTranslation() {
     $settings = Settings::getAll();
diff --git a/core/tests/Drupal/Tests/Component/Serialization/YamlTest.php b/core/tests/Drupal/Tests/Component/Serialization/YamlTest.php
index e8743587f1..f3fc2232e9 100644
--- a/core/tests/Drupal/Tests/Component/Serialization/YamlTest.php
+++ b/core/tests/Drupal/Tests/Component/Serialization/YamlTest.php
@@ -126,7 +126,7 @@ public function providerYamlFilesInCore() {
       if ($dir->getExtension() == 'yml' && strpos($pathname, '/../../../../../node_modules') === FALSE) {
         if (strpos($dir->getRealPath(), 'invalid_file') !== FALSE) {
           // There are some intentionally invalid files provided for testing
-          // library API behaviours, ignore them.
+          // library API behaviors, ignore them.
           continue;
         }
         $files[] = [$dir->getRealPath()];
diff --git a/core/tests/Drupal/Tests/Component/Utility/UrlHelperTest.php b/core/tests/Drupal/Tests/Component/Utility/UrlHelperTest.php
index 7b9bd1c40e..613ecfffbe 100644
--- a/core/tests/Drupal/Tests/Component/Utility/UrlHelperTest.php
+++ b/core/tests/Drupal/Tests/Component/Utility/UrlHelperTest.php
@@ -599,7 +599,7 @@ public function providerTestExternalIsLocal() {
       ['http://example.com/foo', 'http://example.com/bar', FALSE],
       ['http://example.com', 'http://example.com/bar', FALSE],
       ['http://example.com/bar', 'http://example.com/bar/', FALSE],
-      // Ensure \ is normalised to / since some browsers do that.
+      // Ensure \ is normalized to / since some browsers do that.
       ['http://www.example.ca\@example.com', 'http://example.com', FALSE],
       // Some browsers ignore or strip leading control characters.
       ["\x00//www.example.ca", 'http://example.com', FALSE],
diff --git a/core/tests/Drupal/Tests/Core/Render/Element/HtmlTagTest.php b/core/tests/Drupal/Tests/Core/Render/Element/HtmlTagTest.php
index 51ac995c19..96777a6e70 100644
--- a/core/tests/Drupal/Tests/Core/Render/Element/HtmlTagTest.php
+++ b/core/tests/Drupal/Tests/Core/Render/Element/HtmlTagTest.php
@@ -75,7 +75,7 @@ public function providerPreRenderHtmlTag() {
     $element['#noscript'] = TRUE;
     $tags['noscript'] = [$element, '<noscript><div class="test" id="id">value</div>' . "\n" . '</noscript>'];
 
-    // Ensure that #tag is sanitised.
+    // Ensure that #tag is sanitized.
     $element = [
       '#tag' => 'p><script>alert()</script><p',
       '#value' => 'value',
diff --git a/core/tests/Drupal/Tests/Core/Security/RequestSanitizerTest.php b/core/tests/Drupal/Tests/Core/Security/RequestSanitizerTest.php
index 2301fea2f9..7aac8f108b 100644
--- a/core/tests/Drupal/Tests/Core/Security/RequestSanitizerTest.php
+++ b/core/tests/Drupal/Tests/Core/Security/RequestSanitizerTest.php
@@ -61,7 +61,7 @@ public function testRequestSanitization(Request $request, array $expected = [],
 
     $request = RequestSanitizer::sanitize($request, $whitelist, is_null($expected_errors) ? FALSE : TRUE);
 
-    // Normalise the expected data.
+    // Normalize the expected data.
     $expected += ['cookies' => [], 'query' => [], 'request' => []];
     $expected_query_string = http_build_query($expected['query']);
 
diff --git a/core/themes/claro/claro.libraries.yml b/core/themes/claro/claro.libraries.yml
index dc1972693e..99baaeb38c 100644
--- a/core/themes/claro/claro.libraries.yml
+++ b/core/themes/claro/claro.libraries.yml
@@ -71,7 +71,7 @@ global-styling:
     # such as inputs, action links, buttons, dropbuttons. For usability and
     # accessibility reasons, we keep target sizes big enough on touch screen
     # devices (by not making these elements smaller than their default size).
-    # Modernizr is used for recognising whether user is using a touch device or
+    # Modernizr is used for recognizing whether user is using a touch device or
     # not. This allows conditionally rendering small variation of the control
     # elements on non-touch devices. In some cases, such as when rendering
     # links, it is hard recognize when Modernizr should be attached, therefore
diff --git a/core/themes/claro/js/nav-tabs.es6.js b/core/themes/claro/js/nav-tabs.es6.js
index 9971585319..44edaa1f7b 100644
--- a/core/themes/claro/js/nav-tabs.es6.js
+++ b/core/themes/claro/js/nav-tabs.es6.js
@@ -73,7 +73,7 @@
       .trigger('resize.tabs');
   }
   /**
-   * Initialise the tabs JS.
+   * Initialize the tabs JS.
    */
   Drupal.behaviors.navTabs = {
     attach(context) {
diff --git a/core/themes/seven/js/nav-tabs.es6.js b/core/themes/seven/js/nav-tabs.es6.js
index 2100b6608f..06400b329f 100644
--- a/core/themes/seven/js/nav-tabs.es6.js
+++ b/core/themes/seven/js/nav-tabs.es6.js
@@ -38,7 +38,7 @@
   }
 
   /**
-   * Initialise the tabs JS.
+   * Initialize the tabs JS.
    */
   Drupal.behaviors.navTabs = {
     attach(context, settings) {
diff --git a/sites/default/default.settings.php b/sites/default/default.settings.php
index 76e509abeb..45b0cca64e 100644
--- a/sites/default/default.settings.php
+++ b/sites/default/default.settings.php
@@ -440,7 +440,7 @@
 /**
  * Class Loader.
  *
- * If the APCu extension is detected, the classloader will be optimised to use
+ * If the APCu extension is detected, the classloader will be optimized to use
  * it. Set to FALSE to disable this.
  *
  * @see https://getcomposer.org/doc/articles/autoloader-optimization.md
diff --git a/sites/example.settings.local.php b/sites/example.settings.local.php
index 520cb4acd5..f91b9afb29 100644
--- a/sites/example.settings.local.php
+++ b/sites/example.settings.local.php
@@ -131,15 +131,15 @@
 $settings['skip_permissions_hardening'] = TRUE;
 
 /**
- * Exclude modules from configuration synchronisation.
+ * Exclude modules from configuration synchronization.
  *
  * On config export sync, no config or dependent config of any excluded module
  * is exported. On config import sync, any config of any installed excluded
  * module is ignored. In the exported configuration, it will be as if the
  * excluded module had never been installed. When syncing configuration, if an
  * excluded module is already installed, it will not be uninstalled by the
- * configuration synchronisation, and dependent configuration will remain
- * intact. This affects only configuration synchronisation; single import and
+ * configuration synchronization, and dependent configuration will remain
+ * intact. This affects only configuration synchronization; single import and
  * export of configuration are not affected.
  *
  * Drupal does not validate or sanity check the list of excluded modules. For
@@ -148,7 +148,7 @@
  * anymore.
  *
  * This is an advanced feature and using it means opting out of some of the
- * guarantees the configuration synchronisation provides. It is not recommended
+ * guarantees the configuration synchronization provides. It is not recommended
  * to use this feature with modules that affect Drupal in a major way such as
  * the language or field module.
  */

diff --git a/core/modules/rdf/tests/src/Traits/EasyRdf_ParsedUri.php b/core/modules/rdf/tests/src/Traits/EasyRdf_ParsedUri.php
index 2c2aa7893e..e433d46bfb 100644
--- a/core/modules/rdf/tests/src/Traits/EasyRdf_ParsedUri.php
+++ b/core/modules/rdf/tests/src/Traits/EasyRdf_ParsedUri.php
@@ -6,7 +6,7 @@
 /**
  * This is copy of \EasyRdf_ParsedUri from the easyrdf/easyrdf library.
  *
  * It fixes a PHP 7.4 deprecation in \EasyRdf_ParsedUri::normalise().
  *
  * @todo https://www.drupal.org/project/drupal/issues/3110972 Remove this work
  *   around.
@@ -204,14 +204,14 @@ public function setFragment($fragment)
 
 
     /**
-     * Normalises the path of this URI if it has one. Normalising a path means
+     * Normalizes the path of this URI if it has one. Normalizing a path means
      * that any unnecessary '.' and '..' segments are removed. For example, the
-     * URI http://example.com/a/b/../c/./d would be normalised to
+     * URI http://example.com/a/b/../c/./d would be normalized to
      * http://example.com/a/c/d
      *
      * @return object EasyRdf_ParsedUri
      */
-    public function normalise()
+    public function normalize()
     {
         if (empty($this->path)) {
             return $this;
@@ -253,7 +253,7 @@ public function normalise()
             }
         }
 
-        // Construct the new normalised path
+        // Construct the new normalized path
         $this->path = implode('/', $newSegments);
 
         // Allow easy chaining of methods
@@ -313,7 +313,7 @@ public function resolve($relUri)
 
         $target->fragment = $relUri->fragment;
 
-        $target->normalise();
+        $target->normalize();
 
         return $target;
     }
@@ -6,7 +6,7 @@
  * This is copy of \EasyRdf_ParsedUri from the easyrdf/easyrdf library.
  *
- * It fixes a PHP 7.4 deprecation in \EasyRdf_ParsedUri::normalise().
+ * It fixes a PHP 7.4 deprecation in \EasyRdf_ParsedUri::normalize().
  *
  * @todo https://www.drupal.org/project/drupal/issues/3110972 Remove this work